@@ -46,11 +46,11 @@ from .literals import (
     TargetDbTypeType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -279,7 +279,7 @@ CertificateTypeDef = TypedDict(
         "CertificateIdentifier": str,
         "CertificateCreationDate": datetime,
         "CertificatePem": str,
-        "CertificateWallet": bytes,
+        "CertificateWallet": StreamingBody,
         "CertificateArn": str,
         "CertificateOwner": str,
         "ValidFromDate": datetime,
